@@ -14,7 +14,7 @@ DOCOMO_STATUS_SET = ('TB', 'TC', 'TD', 'TJ')
 DOCOMO_VENDOR_RE = re.compile(r'([A-Z]+)\d')
 
 FOMA_SERIES_4DIGITS_RE = re.compile(r'\d{4}')
-FOMA_SERIES_3DIGITS_RE = re.compile(r'(\d{3}i|\d{2}[ABC])')
+FOMA_SERIES_3DIGITS_RE = re.compile(r'(\d{3}i|\d{2}[ABC][23]?)')
 
 DOCOMO_COMMENT_RE = re.compile(r'\((.+?)\)')
 DOCOMO_DISPLAY_BYTES_RE = re.compile(r'^W(\d+)H(\d+)$')
@@ -29,7 +29,7 @@ DOCOMO_HTML_VERSION_LIST = [
         (re.compile('902i|702i|851iWM|882i|883i$|^N601i$|^D800iDS$|^P70[34]imyu$'), '6.0'),
         (re.compile('883iES|903i|703i|904i|704i'), '7.0'),
         (re.compile('905i|705i'), '7.1'),
-        (re.compile('906i|0[1-9]A'), '7.2'),
+        (re.compile('906i|0[1-9]A[23]?'), '7.2'),
         ]
 
 def _get_docomo_html_version(model):
